==> haskell-crypto-api-tests-0.3-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-api-tests.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-api-tests
version: 0.3
id: crypto-api-tests-0.3-JolFNmqipWYH7iXiBieTXi
key: crypto-api-tests-0.3-JolFNmqipWYH7iXiBieTXi
license: BSD-3-Clause
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: http://trac.haskell.org/crypto-api/wiki
synopsis: A test framework and KATs for cryptographic operations.
description:
    A test framework for hash and cipher operations using
    the crypto-api interface.  Known answer tests (KATs)
    for common cryptographic algorithms are included.
    Patches welcome (both adding KATs for more algorithms
    or property tests for classes of algorithms).
category: Data, Cryptography
abi: 54d6594c39fd213a76b6bc65b299fa53
exposed: True
exposed-modules:
    Test.AES Test.Crypto Test.HMAC Test.MD5 Test.ParseNistKATs Test.SHA
    Test.TwoFish
hidden-modules: Paths_crypto_api_tests
import-dirs: /usr/lib/ghc-8.6.1/site-local/crypto-api-tests-0.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/crypto-api-tests-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/crypto-api-tests-0.3
hs-libraries: HScrypto-api-tests-0.3-JolFNmqipWYH7iXiBieTXi
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    QuickCheck-2.11.3-BDoyaQh2Mcq3pIdI4VETKc base-4.12.0.0
    bytestring-0.10.8.2 cereal-0.5.7.0-2uER3Agem8P6aYfM1x47n8
    crypto-api-0.13.3-43rwgg6didD9Ww3YkDbwy5 directory-1.3.3.0
    filepath-1.4.2.1 test-framework-0.8.2.0-9xKSmZ6qZ74nvowfP3MHj
    test-framework-hunit-0.3.0.2-1wKogXplU49IUVucyLf4KT
    test-framework-quickcheck2-0.3.0.5-JGlmKpQkAejAIRsTEWgJkx
haddock-interfaces: /usr/share/doc/haskell-crypto-api-tests/html/crypto-api-tests.haddock
haddock-html: /usr/share/doc/haskell-crypto-api-tests/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-api-tests-0.3-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-api-tests.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-api-tests
version: 0.3
id: crypto-api-tests-0.3-F6JT4dk5Y6vG8W0VGiYn1E
key: crypto-api-tests-0.3-F6JT4dk5Y6vG8W0VGiYn1E
license: BSD-3-Clause
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: http://trac.haskell.org/crypto-api/wiki
synopsis: A test framework and KATs for cryptographic operations.
description:
    A test framework for hash and cipher operations using
    the crypto-api interface.  Known answer tests (KATs)
    for common cryptographic algorithms are included.
    Patches welcome (both adding KATs for more algorithms
    or property tests for classes of algorithms).
category: Data, Cryptography
abi: d52e3e17a557488d2ded93db943f7b1b
exposed: True
exposed-modules:
    Test.AES Test.Crypto Test.HMAC Test.MD5 Test.ParseNistKATs Test.SHA
    Test.TwoFish
hidden-modules: Paths_crypto_api_tests
import-dirs: /usr/lib/ghc-8.6.1/site-local/crypto-api-tests-0.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/crypto-api-tests-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/crypto-api-tests-0.3
hs-libraries: HScrypto-api-tests-0.3-F6JT4dk5Y6vG8W0VGiYn1E
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    QuickCheck-2.11.3-BDoyaQh2Mcq3pIdI4VETKc base-4.12.0.0
    bytestring-0.10.8.2 cereal-0.5.7.0-2uER3Agem8P6aYfM1x47n8
    crypto-api-0.13.3-43rwgg6didD9Ww3YkDbwy5 directory-1.3.3.0
    filepath-1.4.2.1 test-framework-0.8.2.0-KO57kWdke3eEL9xLOoYXmM
    test-framework-hunit-0.3.0.2-56lKZ4LQaDN7cJJlr8lggF
    test-framework-quickcheck2-0.3.0.5-CDuUzUYSon17K6J0yuJi6B
haddock-interfaces: /usr/share/doc/haskell-crypto-api-tests/html/crypto-api-tests.haddock
haddock-html: /usr/share/doc/haskell-crypto-api-tests/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
